Install *spacytextblob* from PyPi.

## PyPi

```bash
pip install spacytextblob
```

## Data and models

TextBlob requires additional data to be downloaded before getting started.

```bash
python -m textblob.download_corpora
```

spaCy also requires that you download a model to get started.

```bash
python -m spacy download en_core_web_sm
```
